pub struct RestrictionList {
pub restrictions: Vec<Restriction>,
}Expand description
RestrictionList : A list of restrictions for the specified Amazon catalog item.
Fields
restrictions: Vec<Restriction>Implementations
sourceimpl RestrictionList
impl RestrictionList
sourcepub fn new(restrictions: Vec<Restriction>) -> RestrictionList
pub fn new(restrictions: Vec<Restriction>) -> RestrictionList
A list of restrictions for the specified Amazon catalog item.